@@ -2,34 +2,35 @@
 
 Create a distribution's .egg-info directory and contents"""
 
-from distutils.filelist import FileList as _FileList
-from distutils.errors import DistutilsInternalError
-from distutils.util import convert_path
-from distutils import log
-import distutils.errors
-import distutils.filelist
+import collections
 import functools
 import os
 import re
 import sys
 import time
-import collections
-
-from .._importlib import metadata
-from .. import _entry_points, _normalization
-from . import _requirestxt
-
-from setuptools import Command
-from setuptools.command.sdist import sdist
-from setuptools.command.sdist import walk_revctrl
-from setuptools.command.setopt import edit_config
-from setuptools.command import bdist_egg
-import setuptools.unicode_utils as unicode_utils
-from setuptools.glob import glob
 
 import packaging
-from ..warnings import SetuptoolsDeprecationWarning
+import packaging.requirements
+import packaging.version
 
+import setuptools.unicode_utils as unicode_utils
+from setuptools import Command
+from setuptools.command import bdist_egg
+from setuptools.command.sdist import sdist, walk_revctrl
+from setuptools.command.setopt import edit_config
+from setuptools.glob import glob
+
+from .. import _entry_points, _normalization
+from .._importlib import metadata
+from ..warnings import SetuptoolsDeprecationWarning
+from . import _requirestxt
+
+import distutils.errors
+import distutils.filelist
+from distutils import log
+from distutils.errors import DistutilsInternalError
+from distutils.filelist import FileList as _FileList
+from distutils.util import convert_path
 
 PY_MAJOR = '{}.{}'.format(*sys.version_info)
 
