@@ -1,17 +1,20 @@
 from __future__ import annotations
 
-from collections.abc import Callable
-from distutils.errors import DistutilsArgError
-import inspect
 import glob
+import inspect
 import platform
-import distutils.command.install as orig
+from collections.abc import Callable
 from typing import Any, ClassVar, cast
 
 import setuptools
+
+from ..dist import Distribution
 from ..warnings import SetuptoolsDeprecationWarning, SetuptoolsWarning
 from .bdist_egg import bdist_egg as bdist_egg_cls
 
+import distutils.command.install as orig
+from distutils.errors import DistutilsArgError
+
 # Prior to numpy 1.9, NumPy relies on the '_install' name, so provide it for
 # now. See https://github.com/pypa/setuptools/issues/199/
 _install = orig.install
@@ -20,6 +23,8 @@ _install = orig.install
 class install(orig.install):
     """Use easy_install to install the package, w/dependencies"""
 
+    distribution: Distribution  # override distutils.dist.Distribution with setuptools.dist.Distribution
+
     user_options = orig.install.user_options + [
         ('old-and-unmanageable', None, "Try not to use this!"),
         (
